@@ -27,7 +27,7 @@ GENERAL_AG.add_argument(
     ))
 GENERAL_AG.add_argument(
     '--config',
-    help='Path to configuration file.')
+    help='Path to configuration file. Can be a comma separated list of files.')
 GENERAL_AG.add_argument(
     '--cumulus-version',
     action='count',
@@ -50,6 +50,10 @@ ACTIONS_AG.add_argument(
     '--deploy-without-bundling',
     action='count',
     help='Deploy all stacks in the environment, without bundling first')
+ACTIONS_AG.add_argument(
+    '--redeploy',
+    action='count',
+    help='Undeploy and deploy the stack(s). Implies bundling.')
 ACTIONS_AG.add_argument(
     '--events',
     action='count',
